/**
 * @author Heidi Lee
 * 
 * Description: This program incorporates multiple concepts that we have covered in
 *     class, such as the use of images, key clicks, mouse clicks, and movement.
 *     Through these concepts, it will display certain memes (doge, grumpy cat, bolbi)
 *     depending on the key click, and will display the image with sunglasses on (or off)
 *     when the mouse is clicked.
 * 
 *     Use 'd' to display doge, 'c' to display grumpy cat, and 'b' to display Bolbi.
 *     Press on the mouse to display sunglasses on/off.
 */

PImage doge, cat, bolbi, sunglasses, fire, hundred;
int charPressed = 'x';
boolean isGlassesOn = false;
int offset = 0;

void setup() {
  size(400, 400);
  background(255);
  doge = loadImage("doge.png");
  cat = loadImage("cat.png");
  bolbi = loadImage("bolbi.png");
  sunglasses = loadImage("sunglasses.png");
  fire = loadImage("fire.png");
  hundred = loadImage("100.png");
}

void draw() {
  emojiMovement();
  displayMeme();
}

/*
 * Helps display the emoji background in the moving motion. Resets the offset
 * when it goes off the screen for the continuous effect
 */
void emojiMovement() {
  if (offset == 400)
    offset = 0;
  backdrop();

  offset += 1;
}

/**
 *  Displays the emoji background
 */
void backdrop() {
  background(255);

  // displays eight fire emoji that moves in a downward motion
  for (int i = -400; i < 400; i+=50) {
    image(fire, 0, offset + 10 + i, 25, 25);
    image(fire, 50, offset + i, 25, 25);
    image(fire, 100, offset + 15 + i, 25, 25);
    image(fire, 150, offset + 5 + i, 25, 25);
    image(fire, 200, offset + 25 + i, 25, 25);
    image(fire, 250, offset + i, 25, 25);
    image(fire, 300, offset + 40 + i, 25, 25);
    image(fire, 350, offset + 20 + i, 25, 25);
  }

  // displays eight 100 percent emoji that moves in an upward motion
  for (int i = 775; i > -25; i-=50) {
    image(hundred, 25, -offset - 20 + i, 25, 25);
    image(hundred, 75, -offset - 15 + i, 25, 25);
    image(hundred, 125, -offset - 5 + i, 25, 25);
    image(hundred, 175, -offset - 25 + i, 25, 25);
    image(hundred, 225, -offset + i, 25, 25);
    image(hundred, 275, -offset - 40 + i, 25, 25);
    image(hundred, 325, -offset - 20 + i, 25, 25);
    image(hundred, 375, -offset - 20 + i, 25, 25);
  }
}

/**
 * Depending on what key was clicked, display the respective image. If the
 * mouse was clicked, then display the sunglasses
 */
void displayMeme() {
  // displays doge image
  if (charPressed == 'd') {
    image(doge, 50, 50, 300, 300);
    if (isGlassesOn)
      image(sunglasses, 80, 85, 250, 200);
  }

  // displays cat image
  if (charPressed == 'c') {
    image(cat, 50, 50, 300, 300); 
    if (isGlassesOn)
      image(sunglasses, 80, 115, 250, 200);
  }

  // displays bolbi image
  if (charPressed == 'b') {
    image(bolbi, 50, 50, 300, 300); 
    if (isGlassesOn)
      image(sunglasses, 55, 60, 265, 235);
  }
}

/**
 * Stores whether glasses are on or off, depending if the mouse was clicked
 */
void mousePressed() {
  isGlassesOn = !isGlassesOn;
}

/**
 * Stores whichever key was pressed into charPressed
 */
void keyReleased() {
  charPressed = key;
}